﻿Imports variables_globales
Imports accesoBDeRestaurante.cliente_bd
Imports accesoBDeRestaurante.usuario_bd
Imports accesoBDeRestaurante.pedido_bd

Partial Class camarero_Clientes
    Inherits System.Web.UI.Page

    Protected Const Ret_Vacio As Integer = -1
    Protected Const Ret_Error As Integer = 0
    Protected Const Ret_Correcto As Integer = 1
    Protected Const Ret_NoPedido As Integer = -2

    Protected Sub Page_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Load
        Dim ret_ok As Boolean = True

        Try
            ' Carga de los datos sólo una vez, cuando la página carga
            If Not IsPostBack Then

                InicializarDatos()
                ActualizarDatos()

            End If
        Catch ex As Exception
            Me.MsgErrorPanel.Visible = True
            Me.MsgErrorLbl.Text = "Ha habido un problema al mostrar los clientes"
        End Try
    End Sub

    Protected Sub InicializarDatos()
        Me.ClientesGridView.DataSource = Nothing
        Me.ClientesGridView.DataBind()
        Me.MsgEstadoLbl.Visible = False
        Me.MsgErrorPanel.Visible = False
    End Sub

    Protected Sub ActualizarDatos()
        Dim ret_ok As Boolean = True

        Select Case ActualizarGridView()
            Case Ret_Vacio
                MsgEstadoLbl.Text = "No hay clientes registrados"
                MsgEstadoLbl.Visible = True
            Case Ret_Error
                ret_ok = False
            Case Ret_Correcto
                Me.MsgEstadoLbl.Visible = False
                Me.MsgErrorPanel.Visible = False
        End Select

        If ret_ok = Ret_Error Then
            Throw New Exception()
        End If
    End Sub

    Protected Function ActualizarGridView() As Integer
        Dim ret_ok As Integer

        ret_ok = LlenarGridView()
        Me.ClientesGridView.DataBind()

        Return ret_ok
    End Function

    Protected Function LlenarGridView() As Integer
        Dim ret_ok As Integer = Ret_Correcto
        Dim MyDataAdapter As MySql.Data.MySqlClient.MySqlDataAdapter
        Dim MyDataSet As New Data.DataSet
        Dim comando As MySql.Data.MySqlClient.MySqlCommand

        Try

            ' Recupero los clientes del restaurante
            comando = get_todos_clientes_str(cadena_conexion)

            MyDataAdapter = New MySql.Data.MySqlClient.MySqlDataAdapter(comando)
            MyDataSet.Clear()
            MyDataAdapter.Fill(MyDataSet)
            If MyDataSet.Tables(0).Rows.Count = 0 Then
                ret_ok = Ret_Vacio
            Else
                Me.ClientesGridView.DataSource = MyDataSet.Tables(0)
            End If

        Catch ex As Exception
            ret_ok = Ret_Error
        End Try

        Return ret_ok
    End Function

    Protected Function EliminarCliente(ByVal index As Integer) As Integer
        Dim tmp_cliente_clave As cliente_clave
        Dim tmp_cliente_reg As cliente_reg
        Dim tmp_usuario_clave As usuario_clave
        Dim ret_ok As Integer = 1

        Try
            tmp_cliente_clave.id = CInt(Me.ClientesGridView.Rows(index).Cells(1).Text)
            If existe_cliente(tmp_cliente_clave, cadena_conexion) Then
                tmp_cliente_reg = get_cliente(tmp_cliente_clave, cadena_conexion)
                If es_error_pedido(get_pedido_actual(tmp_cliente_clave, cadena_conexion)) Then
                    tmp_usuario_clave.id = tmp_cliente_reg.FK_usuario
                    If Not eliminar_usuario(tmp_usuario_clave, cadena_conexion) Then
                        ret_ok = 0
                    End If
                Else
                    ret_ok = 2
                End If
            Else
                ret_ok = 0
            End If
        Catch ex As Exception
            ret_ok = 0
        End Try

        Return ret_ok
    End Function

    Protected Function ObtenerPrimeraFilaSeleccionada() As Integer
        Dim result As Integer

        For Each row As GridViewRow In Me.ClientesGridView.Rows
            Dim ch As CheckBox = CType(row.FindControl("SelectCheck"), CheckBox)
            If ch.Checked Then
                result = CInt(row.Cells(1).Text)
                Return result
            End If
        Next

        Return -1
    End Function

    Protected Sub ClientesGridView_PageIndexChanging(ByVal sender As Object, ByVal e As System.Web.UI.WebControls.GridViewPageEventArgs) Handles ClientesGridView.PageIndexChanging
        Me.ClientesGridView.PageIndex = e.NewPageIndex()
        InicializarDatos()

        If ActualizarGridView() Then
            Me.MsgEstadoLbl.Visible = False
        Else
            Me.MsgEstadoLbl.Visible = True
        End If

        Try
            If Me.ClientesGridView.SelectedIndex <> -1 Then
                If Me.ClientesGridView.SelectedIndex Mod 2 = 0 Then
                    Me.ClientesGridView.Rows(Me.ClientesGridView.SelectedIndex).RowState = DataControlRowState.Normal
                Else
                    Me.ClientesGridView.Rows(Me.ClientesGridView.SelectedIndex).RowState = DataControlRowState.Alternate
                End If
            End If
        Catch ex As Exception

        End Try
    End Sub

    Protected Sub PedidoGridView_RowDeleting(ByVal sender As Object, ByVal e As System.Web.UI.WebControls.GridViewDeleteEventArgs) Handles ClientesGridView.RowDeleting
        Dim ret_ok As Integer = 0

        ret_ok = EliminarCliente(e.RowIndex)

        If ret_ok = 1 Then
            Select Case ActualizarGridView()
                Case Ret_Vacio
                    MsgEstadoLbl.Text = "No hay clientes registrados"
                    MsgEstadoLbl.Visible = True
                Case Ret_Error
                    ret_ok = False
            End Select
        ElseIf ret_ok = 2 Then
            MsgErrorLbl.Text = "El cliente no se puede eliminar porque tiene un pedido activo."
            MsgErrorPanel.Visible = True
        Else
            MsgErrorLbl.Text = "Error al eliminar el cliente, vuelva a intentarlo o consulte al administrador.<br>Disculpe las molestias"
            MsgErrorPanel.Visible = True
        End If
    End Sub

    Protected Sub DetallesClienteButton_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles DetallesClienteButton.Click
        Dim cliente As cliente_clave

        Try
            cliente.id = ObtenerPrimeraFilaSeleccionada()
            If existe_cliente(cliente, cadena_conexion) Then
                Response.Redirect("DetallesCliente.aspx?id=" & cliente.id & "&nav=" & Trim(Me.CaminoLbl.Text) & "&pag=Clientes.aspx")
            Else
                Throw New Exception()
            End If
        Catch ex As Exception
            Me.MsgErrorPanel.Visible = True
            Me.MsgErrorLbl.Text = "Debe seleccionar un cliente para ver los detalles."
        End Try
    End Sub
End Class
